summaryrefslogtreecommitdiff
path: root/basic/source/inc
diff options
context:
space:
mode:
Diffstat (limited to 'basic/source/inc')
-rwxr-xr-x[-rw-r--r--]basic/source/inc/buffer.hxx30
-rwxr-xr-x[-rw-r--r--]basic/source/inc/codegen.hxx28
-rwxr-xr-x[-rw-r--r--]basic/source/inc/collelem.hxx0
-rwxr-xr-x[-rw-r--r--]basic/source/inc/disas.hxx14
-rwxr-xr-x[-rw-r--r--]basic/source/inc/dlgcont.hxx0
-rwxr-xr-x[-rw-r--r--]basic/source/inc/errobject.hxx0
-rwxr-xr-x[-rw-r--r--]basic/source/inc/expr.hxx84
-rwxr-xr-x[-rw-r--r--]basic/source/inc/filefmt.hxx108
-rwxr-xr-x[-rw-r--r--]basic/source/inc/image.hxx44
-rwxr-xr-x[-rw-r--r--]basic/source/inc/iosys.hxx12
-rwxr-xr-x[-rw-r--r--]basic/source/inc/namecont.hxx0
-rwxr-xr-x[-rw-r--r--]basic/source/inc/object.hxx10
-rwxr-xr-x[-rw-r--r--]basic/source/inc/opcodes.hxx0
-rwxr-xr-x[-rw-r--r--]basic/source/inc/parser.hxx46
-rwxr-xr-x[-rw-r--r--]basic/source/inc/propacc.hxx6
-rwxr-xr-x[-rw-r--r--]basic/source/inc/runtime.hxx158
-rwxr-xr-x[-rw-r--r--]basic/source/inc/sbcomp.hxx0
-rwxr-xr-x[-rw-r--r--]basic/source/inc/sbintern.hxx12
-rwxr-xr-x[-rw-r--r--]basic/source/inc/sbjsmeth.hxx0
-rwxr-xr-x[-rw-r--r--]basic/source/inc/sbjsmod.hxx4
-rwxr-xr-xbasic/source/inc/sbtrace.hxx44
-rwxr-xr-x[-rw-r--r--]basic/source/inc/sbunoobj.hxx48
-rwxr-xr-x[-rw-r--r--]basic/source/inc/scanner.hxx54
-rwxr-xr-x[-rw-r--r--]basic/source/inc/scriptcont.hxx1
-rwxr-xr-x[-rw-r--r--]basic/source/inc/stdobj.hxx2
-rwxr-xr-x[-rw-r--r--]basic/source/inc/symtbl.hxx136
-rwxr-xr-x[-rw-r--r--]basic/source/inc/token.hxx32
27 files changed, 466 insertions, 407 deletions
diff --git a/basic/source/inc/buffer.hxx b/basic/source/inc/buffer.hxx
index 7a6a2092693d..24c4bc002f60 100644..100755
--- a/basic/source/inc/buffer.hxx
+++ b/basic/source/inc/buffer.hxx
@@ -38,27 +38,27 @@ class SbiBuffer { // Code/Konstanten-Puffer:
SbiParser* pParser; // fuer Fehlermeldungen
char* pBuf; // Puffer-Pointer
char* pCur; // aktueller Puffer-Pointer
- UINT32 nOff; // aktuelles Offset
- UINT32 nSize; // aktuelle Groesse
+ sal_uInt32 nOff; // aktuelles Offset
+ sal_uInt32 nSize; // aktuelle Groesse
short nInc; // Inkrement
- BOOL Check( USHORT ); // Buffergroesse testen
+ sal_Bool Check( sal_uInt16 ); // Buffergroesse testen
public:
SbiBuffer( SbiParser*, short ); // Inkrement
~SbiBuffer();
- void Patch( UINT32, UINT32 ); // Patchen
- void Chain( UINT32 ); // Back-Chain
- void Align( INT32 ); // Alignment
- BOOL Add( const void*, USHORT );// Element anfuegen
- BOOL operator += (const String&);// Basic-String speichern
- BOOL operator += (INT8); // Zeichen speichern
- BOOL operator += (INT16); // Integer speichern
- BOOL operator += (UINT8); // Zeichen speichern
- BOOL operator += (UINT16); // Integer speichern
- BOOL operator += (UINT32); // Integer speichern
- BOOL operator += (INT32); // Integer speichern
+ void Patch( sal_uInt32, sal_uInt32 ); // Patchen
+ void Chain( sal_uInt32 ); // Back-Chain
+ void Align( sal_Int32 ); // Alignment
+ sal_Bool Add( const void*, sal_uInt16 );// Element anfuegen
+ sal_Bool operator += (const String&);// Basic-String speichern
+ sal_Bool operator += (sal_Int8); // Zeichen speichern
+ sal_Bool operator += (sal_Int16); // Integer speichern
+ sal_Bool operator += (sal_uInt8); // Zeichen speichern
+ sal_Bool operator += (sal_uInt16); // Integer speichern
+ sal_Bool operator += (sal_uInt32); // Integer speichern
+ sal_Bool operator += (sal_Int32); // Integer speichern
char* GetBuffer(); // Puffer rausgeben (selbst loeschen!)
char* GetBufferPtr(){ return pBuf; }
- UINT32 GetSize() { return nOff; }
+ sal_uInt32 GetSize() { return nOff; }
};
#endif
diff --git a/basic/source/inc/codegen.hxx b/basic/source/inc/codegen.hxx
index cfafcddec8e0..21d19312fd17 100644..100755
--- a/basic/source/inc/codegen.hxx
+++ b/basic/source/inc/codegen.hxx
@@ -41,28 +41,28 @@ class SbiCodeGen { // Code-Erzeugung:
SbiBuffer aCode; // Code-Puffer
short nLine, nCol; // Zeile, Spalte fuer Stmnt-Befehl
short nForLevel; // #29955 for-Schleifen-Ebene
- BOOL bStmnt; // TRUE: Statement-Opcode liegt an
+ sal_Bool bStmnt; // sal_True: Statement-Opcode liegt an
public:
SbiCodeGen( SbModule&, SbiParser*, short );
SbiParser* GetParser() { return pParser; }
SbModule& GetModule() { return rMod; }
- UINT32 Gen( SbiOpcode );
- UINT32 Gen( SbiOpcode, UINT32 );
- UINT32 Gen( SbiOpcode, UINT32, UINT32 );
- void Patch( UINT32 o, UINT32 v ){ aCode.Patch( o, v ); }
- void BackChain( UINT32 off ) { aCode.Chain( off ); }
+ sal_uInt32 Gen( SbiOpcode );
+ sal_uInt32 Gen( SbiOpcode, sal_uInt32 );
+ sal_uInt32 Gen( SbiOpcode, sal_uInt32, sal_uInt32 );
+ void Patch( sal_uInt32 o, sal_uInt32 v ){ aCode.Patch( o, v ); }
+ void BackChain( sal_uInt32 off ) { aCode.Chain( off ); }
void Statement();
void GenStmnt(); // evtl. Statement-Opcode erzeugen
- UINT32 GetPC();
- UINT32 GetOffset() { return GetPC() + 1; }
+ sal_uInt32 GetPC();
+ sal_uInt32 GetOffset() { return GetPC() + 1; }
void Save();
// #29955 for-Schleifen-Ebene pflegen
void IncForLevel( void ) { nForLevel++; }
void DecForLevel( void ) { nForLevel--; }
- static UINT32 calcNewOffSet( BYTE* pCode, UINT16 nOffset );
- static UINT16 calcLegacyOffSet( BYTE* pCode, UINT32 nOffset );
+ static sal_uInt32 calcNewOffSet( sal_uInt8* pCode, sal_uInt16 nOffset );
+ static sal_uInt16 calcLegacyOffSet( sal_uInt8* pCode, sal_uInt32 nOffset );
};
@@ -70,8 +70,8 @@ template < class T, class S >
class PCodeBuffConvertor
{
T m_nSize; //
- BYTE* m_pStart;
- BYTE* m_pCnvtdBuf;
+ sal_uInt8* m_pStart;
+ sal_uInt8* m_pCnvtdBuf;
S m_nCnvtdSize; //
// Disable usual copying symantics and bodgy default ctor
@@ -79,11 +79,11 @@ class PCodeBuffConvertor
PCodeBuffConvertor(const PCodeBuffConvertor& );
PCodeBuffConvertor& operator = ( const PCodeBuffConvertor& );
public:
- PCodeBuffConvertor( BYTE* pCode, T nSize ): m_nSize( nSize ), m_pStart( pCode ), m_pCnvtdBuf( NULL ), m_nCnvtdSize( 0 ){ convert(); }
+ PCodeBuffConvertor( sal_uInt8* pCode, T nSize ): m_nSize( nSize ), m_pStart( pCode ), m_pCnvtdBuf( NULL ), m_nCnvtdSize( 0 ){ convert(); }
S GetSize(){ return m_nCnvtdSize; }
void convert();
// Caller owns the buffer returned
- BYTE* GetBuffer() { return m_pCnvtdBuf; }
+ sal_uInt8* GetBuffer() { return m_pCnvtdBuf; }
};
// #111897 PARAM_INFO flags start at 0x00010000 to not
diff --git a/basic/source/inc/collelem.hxx b/basic/source/inc/collelem.hxx
index 2c39e711f993..2c39e711f993 100644..100755
--- a/basic/source/inc/collelem.hxx
+++ b/basic/source/inc/collelem.hxx
diff --git a/basic/source/inc/disas.hxx b/basic/source/inc/disas.hxx
index 93929dab42a9..1756d36bfacf 100644..100755
--- a/basic/source/inc/disas.hxx
+++ b/basic/source/inc/disas.hxx
@@ -38,14 +38,14 @@ class SbiDisas {
const SbiImage& rImg;
SbModule* pMod;
char cLabels[ MAX_LABELS ]; // Bitvektor fuer Labels
- UINT32 nOff; // aktuelle Position
- UINT32 nPC; // Position des Opcodes
+ sal_uInt32 nOff; // aktuelle Position
+ sal_uInt32 nPC; // Position des Opcodes
SbiOpcode eOp; // Opcode
- UINT32 nOp1, nOp2; // Operanden
- UINT32 nParts; // 1, 2 oder 3
- UINT32 nLine; // aktuelle Zeile
- BOOL DisasLine( String& );
- BOOL Fetch(); // naechster Opcode
+ sal_uInt32 nOp1, nOp2; // Operanden
+ sal_uInt32 nParts; // 1, 2 oder 3
+ sal_uInt32 nLine; // aktuelle Zeile
+ sal_Bool DisasLine( String& );
+ sal_Bool Fetch(); // naechster Opcode
public:
SbiDisas( SbModule*, const SbiImage* );
void Disas( SvStream& );
diff --git a/basic/source/inc/dlgcont.hxx b/basic/source/inc/dlgcont.hxx
index 94c10ca86b2e..94c10ca86b2e 100644..100755
--- a/basic/source/inc/dlgcont.hxx
+++ b/basic/source/inc/dlgcont.hxx
diff --git a/basic/source/inc/errobject.hxx b/basic/source/inc/errobject.hxx
index 1e94a3927e93..1e94a3927e93 100644..100755
--- a/basic/source/inc/errobject.hxx
+++ b/basic/source/inc/errobject.hxx
diff --git a/basic/source/inc/iosys.hxx b/basic/source/inc/iosys.hxx
index 6d04889776b7..48d6ce39d506 100644..100755
--- a/basic/source/inc/iosys.hxx
+++ b/basic/source/inc/iosys.hxx
@@ -48,10 +48,10 @@ class SvStream;
class SbiStream {
SvStream* pStrm; // der Stream
- ULONG nExpandOnWriteTo; // bei Schreibzugriff, den Stream
+ sal_uIntPtr nExpandOnWriteTo; // bei Schreibzugriff, den Stream
// bis zu dieser Groesse aufblasen
ByteString aLine; // aktuelle Zeile
- ULONG nLine; // aktuelle Zeilennummer
+ sal_uIntPtr nLine; // aktuelle Zeilennummer
short nLen; // Pufferlaenge
short nMode; // Bits:
short nChan; // aktueller Kanal
@@ -63,9 +63,9 @@ public:
~SbiStream();
SbError Open( short, const ByteString&, short, short, short );
SbError Close();
- SbError Read( ByteString&, USHORT = 0, bool bForceReadingPerByte=false );
+ SbError Read( ByteString&, sal_uInt16 = 0, bool bForceReadingPerByte=false );
SbError Read( char& );
- SbError Write( const ByteString&, USHORT = 0 );
+ SbError Write( const ByteString&, sal_uInt16 = 0 );
bool IsText() const { return (nMode & SBSTRM_BINARY) == 0; }
bool IsRandom() const { return (nMode & SBSTRM_RANDOM) != 0; }
@@ -74,8 +74,8 @@ public:
bool IsAppend() const { return (nMode & SBSTRM_APPEND) != 0; }
short GetBlockLen() const { return nLen; }
short GetMode() const { return nMode; }
- ULONG GetLine() const { return nLine; }
- void SetExpandOnWriteTo( ULONG n ) { nExpandOnWriteTo = n; }
+ sal_uIntPtr GetLine() const { return nLine; }
+ void SetExpandOnWriteTo( sal_uIntPtr n ) { nExpandOnWriteTo = n; }
void ExpandFile();
SvStream* GetStrm() { return pStrm; }
};
diff --git a/basic/source/inc/namecont.hxx b/basic/source/inc/namecont.hxx
index 419230c1c2b6..419230c1c2b6 100644..100755
--- a/basic/source/inc/namecont.hxx
+++ b/basic/source/inc/namecont.hxx
diff --git a/basic/source/inc/object.hxx b/basic/source/inc/object.hxx
index c1fdad21d1ce..1b25ee41a25d 100644..100755
--- a/basic/source/inc/object.hxx
+++ b/basic/source/inc/object.hxx
@@ -59,7 +59,7 @@ using SbxVariable::GetInfo;
public:
#endif
typedef void( SampleObject::*pMeth )
- ( SbxVariable* pThis, SbxArray* pArgs, BOOL bWrite );
+ ( SbxVariable* pThis, SbxArray* pArgs, sal_Bool bWrite );
#if defined ( ICC )
private:
#endif
@@ -73,10 +73,10 @@ private:
static Methods aMethods[]; // Methodentabelle
// Methoden
- void Display( SbxVariable*, SbxArray*, BOOL );
- void Event( SbxVariable*, SbxArray*, BOOL );
- void Square( SbxVariable*, SbxArray*, BOOL );
- void Create( SbxVariable*, SbxArray*, BOOL );
+ void Display( SbxVariable*, SbxArray*, sal_Bool );
+ void Event( SbxVariable*, SbxArray*, sal_Bool );
+ void Square( SbxVariable*, SbxArray*, sal_Bool );
+ void Create( SbxVariable*, SbxArray*, sal_Bool );
// Infoblock auffuellen
SbxInfo* GetInfo( short nIdx );
// Broadcaster Notification
diff --git a/basic/source/inc/opcodes.hxx b/basic/source/inc/opcodes.hxx
index cbc98ac22fd4..cbc98ac22fd4 100644..100755
--- a/basic/source/inc/opcodes.hxx
+++ b/basic/source/inc/opcodes.hxx
diff --git a/basic/source/inc/propacc.hxx b/basic/source/inc/propacc.hxx
index 1381d082dcdd..1497bbc0df9d 100644..100755
--- a/basic/source/inc/propacc.hxx
+++ b/basic/source/inc/propacc.hxx
@@ -56,7 +56,7 @@ class SbPropertyValues: public SbPropertyValuesHelper
NS_UNO::Reference< ::com::sun::star::beans::XPropertySetInfo > _xInfo;
private:
- INT32 GetIndex_Impl( const ::rtl::OUString &rPropName ) const;
+ sal_Int32 GetIndex_Impl( const ::rtl::OUString &rPropName ) const;
public:
SbPropertyValues();
@@ -157,7 +157,7 @@ public:
// XPropertyContainer
virtual void SAL_CALL addProperty( const ::rtl::OUString& Name,
- INT16 Attributes,
+ sal_Int16 Attributes,
const NS_UNO::Any& DefaultValue)
throw( NS_BEANS::PropertyExistException, NS_BEANS::IllegalTypeException,
NS_LANG::IllegalArgumentException, NS_UNO::RuntimeException );
@@ -181,7 +181,7 @@ public:
class StarBASIC;
class SbxArray;
-void RTL_Impl_CreatePropertySet( StarBASIC* pBasic, SbxArray& rPar, BOOL bWrite );
+void RTL_Impl_CreatePropertySet( StarBASIC* pBasic, SbxArray& rPar, sal_Bool bWrite );
#undef NS_BEANS
diff --git a/basic/source/inc/runtime.hxx b/basic/source/inc/runtime.hxx
index b6b0814d1e33..df694e548844 100644..100755
--- a/basic/source/inc/runtime.hxx
+++ b/basic/source/inc/runtime.hxx
@@ -103,10 +103,10 @@ struct SbiForStack { // for/next stack:
// For each support
ForType eForType;
- INT32 nCurCollectionIndex;
- INT32* pArrayCurIndices;
- INT32* pArrayLowerBounds;
- INT32* pArrayUpperBounds;
+ sal_Int32 nCurCollectionIndex;
+ sal_Int32* pArrayCurIndices;
+ sal_Int32* pArrayLowerBounds;
+ sal_Int32* pArrayUpperBounds;
Reference< XEnumeration > xEnumeration;
SbiForStack( void )
@@ -124,8 +124,8 @@ struct SbiForStack { // for/next stack:
struct SbiGosubStack { // GOSUB-Stack:
SbiGosubStack* pNext; // Chain
- const BYTE* pCode; // Return-Pointer
- USHORT nStartForLvl; // #118235: For Level in moment of gosub
+ const sal_uInt8* pCode; // Return-Pointer
+ sal_uInt16 nStartForLvl; // #118235: For Level in moment of gosub
};
#define MAXRECURSION 500 // max. 500 Rekursionen
@@ -150,7 +150,7 @@ public:
#else
::osl::Directory* pDir;
#endif
- INT16 nDirFlags;
+ sal_Int16 nDirFlags;
short nCurDirPos;
String sFullNameToBeChecked;
@@ -192,9 +192,9 @@ class SbiInstance
SbError nErr; // aktueller Fehlercode
String aErrorMsg; // letzte Error-Message fuer $ARG
- USHORT nErl; // aktuelle Fehlerzeile
- BOOL bReschedule; // Flag: TRUE = Reschedule in Hauptschleife
- BOOL bCompatibility; // Flag: TRUE = VBA runtime compatibility mode
+ sal_uInt16 nErl; // aktuelle Fehlerzeile
+ sal_Bool bReschedule; // Flag: sal_True = Reschedule in Hauptschleife
+ sal_Bool bCompatibility; // Flag: sal_True = VBA runtime compatibility mode
ComponentVector_t ComponentVector;
public:
@@ -203,9 +203,9 @@ public:
// #31460 Neues Konzept fuer StepInto/Over/Out,
// Erklaerung siehe runtime.cxx bei SbiInstance::CalcBreakCallLevel()
- USHORT nCallLvl; // Call-Level (wg. Rekursion)
- USHORT nBreakCallLvl; // Call-Level zum Anhalten
- void CalcBreakCallLevel( USHORT nFlags ); // Gemaess Flags setzen
+ sal_uInt16 nCallLvl; // Call-Level (wg. Rekursion)
+ sal_uInt16 nBreakCallLvl; // Call-Level zum Anhalten
+ void CalcBreakCallLevel( sal_uInt16 nFlags ); // Gemaess Flags setzen
SbiInstance( StarBASIC* );
~SbiInstance();
@@ -222,14 +222,14 @@ public:
SbError GetErr() { return nErr; }
String GetErrorMsg() { return aErrorMsg; }
xub_StrLen GetErl() { return nErl; }
- void EnableReschedule( BOOL bEnable ) { bReschedule = bEnable; }
- BOOL IsReschedule( void ) { return bReschedule; }
- void EnableCompatibility( BOOL bEnable ) { bCompatibility = bEnable; }
- BOOL IsCompatibility( void ) { return bCompatibility; }
+ void EnableReschedule( sal_Bool bEnable ) { bReschedule = bEnable; }
+ sal_Bool IsReschedule( void ) { return bReschedule; }
+ void EnableCompatibility( sal_Bool bEnable ) { bCompatibility = bEnable; }
+ sal_Bool IsCompatibility( void ) { return bCompatibility; }
ComponentVector_t& getComponentVector( void ) { return ComponentVector; }
- SbMethod* GetCaller( USHORT );
+ SbMethod* GetCaller( sal_uInt16 );
SbModule* GetActiveModule();
SbxArray* GetLocals( SbMethod* );
@@ -269,9 +269,11 @@ struct RefSaveItem
class SbiRuntime
{
+ friend void SbRtl_CallByName( StarBASIC* pBasic, SbxArray& rPar, sal_Bool bWrite );
+
typedef void( SbiRuntime::*pStep0 )();
- typedef void( SbiRuntime::*pStep1 )( UINT32 nOp1 );
- typedef void( SbiRuntime::*pStep2 )( UINT32 nOp1, UINT32 nOp2 );
+ typedef void( SbiRuntime::*pStep1 )( sal_uInt32 nOp1 );
+ typedef void( SbiRuntime::*pStep2 )( sal_uInt32 nOp1, sal_uInt32 nOp2 );
static pStep0 aStep0[]; // Opcode-Tabelle Gruppe 0
static pStep1 aStep1[]; // Opcode-Tabelle Gruppe 1
static pStep2 aStep2[]; // Opcode-Tabelle Gruppe 2
@@ -291,15 +293,15 @@ class SbiRuntime
SbiArgvStack* pArgvStk; // ARGV-Stack
SbiGosubStack* pGosubStk; // GOSUB stack
SbiForStack* pForStk; // FOR/NEXT-Stack
- USHORT nExprLvl; // Tiefe des Expr-Stacks
- USHORT nGosubLvl; // Zum Vermeiden von Tot-Rekursionen
- USHORT nForLvl; // #118235: Maintain for level
- const BYTE* pCode; // aktueller Code-Pointer
- const BYTE* pStmnt; // Beginn des lezten Statements
- const BYTE* pError; // Adresse des aktuellen Error-Handlers
- const BYTE* pRestart; // Restart-Adresse
- const BYTE* pErrCode; // Restart-Adresse RESUME NEXT
- const BYTE* pErrStmnt; // Restart-Adresse RESUMT 0
+ sal_uInt16 nExprLvl; // Tiefe des Expr-Stacks
+ sal_uInt16 nGosubLvl; // Zum Vermeiden von Tot-Rekursionen
+ sal_uInt16 nForLvl; // #118235: Maintain for level
+ const sal_uInt8* pCode; // aktueller Code-Pointer
+ const sal_uInt8* pStmnt; // Beginn des lezten Statements
+ const sal_uInt8* pError; // Adresse des aktuellen Error-Handlers
+ const sal_uInt8* pRestart; // Restart-Adresse
+ const sal_uInt8* pErrCode; // Restart-Adresse RESUME NEXT
+ const sal_uInt8* pErrStmnt; // Restart-Adresse RESUMT 0
String aLibName; // Lib-Name fuer Declare-Call
SbxArrayRef refParams; // aktuelle Prozedur-Parameter
SbxArrayRef refLocals; // lokale Variable
@@ -307,14 +309,14 @@ class SbiRuntime
// AB, 28.3.2000 #74254, Ein refSaveObj reicht nicht! Neu: pRefSaveList (s.u.)
//SbxVariableRef refSaveObj; // #56368 Bei StepElem Referenz sichern
short nArgc; // aktueller Argc
- BOOL bRun; // TRUE: Programm ist aktiv
- BOOL bError; // TRUE: Fehler behandeln
- BOOL bInError; // TRUE: in einem Fehler-Handler
- BOOL bBlocked; // TRUE: blocked by next call level, #i48868
- BOOL bVBAEnabled;
- USHORT nFlags; // Debugging-Flags
+ sal_Bool bRun; // sal_True: Programm ist aktiv
+ sal_Bool bError; // sal_True: Fehler behandeln
+ sal_Bool bInError; // sal_True: in einem Fehler-Handler
+ sal_Bool bBlocked; // sal_True: blocked by next call level, #i48868
+ sal_Bool bVBAEnabled;
+ sal_uInt16 nFlags; // Debugging-Flags
SbError nError; // letzter Fehler
- USHORT nOps; // Opcode-Zaehler
+ sal_uInt16 nOps; // Opcode-Zaehler
sal_uInt32 m_nLastTime;
RefSaveItem* pRefSaveList; // #74254 Temporaere Referenzen sichern
@@ -343,17 +345,17 @@ class SbiRuntime
}
SbxVariable* FindElement
- ( SbxObject* pObj, UINT32 nOp1, UINT32 nOp2, SbError, BOOL bLocal, BOOL bStatic = FALSE );
- void SetupArgs( SbxVariable*, UINT32 );
+ ( SbxObject* pObj, sal_uInt32 nOp1, sal_uInt32 nOp2, SbError, sal_Bool bLocal, sal_Bool bStatic = sal_False );
+ void SetupArgs( SbxVariable*, sal_uInt32 );
SbxVariable* CheckArray( SbxVariable* );
void PushVar( SbxVariable* ); // Variable push
SbxVariableRef PopVar(); // Variable pop
SbxVariable* GetTOS( short=0 ); // Variable vom TOS holen
void TOSMakeTemp(); // TOS in temp. Variable wandeln
- BOOL ClearExprStack(); // Expr-Stack freigeben
+ sal_Bool ClearExprStack(); // Expr-Stack freigeben
- void PushGosub( const BYTE* ); // GOSUB-Element push
+ void PushGosub( const sal_uInt8* ); // GOSUB-Element push
void PopGosub(); // GOSUB-Element pop
void ClearGosubStack(); // GOSUB-Stack freigeben
@@ -373,7 +375,7 @@ class SbiRuntime
void SetParameters( SbxArray* );// Parameter uebernehmen
// MUSS NOCH IMPLEMENTIERT WERDEN
- void DllCall( const String&, const String&, SbxArray*, SbxDataType, BOOL );
+ void DllCall( const String&, const String&, SbxArray*, SbxDataType, sal_Bool );
// #56204 DIM-Funktionalitaet in Hilfsmethode auslagern (step0.cxx)
void DimImpl( SbxVariableRef refVar );
@@ -381,7 +383,7 @@ class SbiRuntime
// #115829
bool implIsClass( SbxObject* pObj, const String& aClass );
- void StepSETCLASS_impl( UINT32 nOp1, bool bHandleDflt = false );
+ void StepSETCLASS_impl( sal_uInt32 nOp1, bool bHandleDflt = false );
// Die nachfolgenden Routinen werden vom Single Stepper
// gerufen und implementieren die einzelnen Opcodes
@@ -404,40 +406,40 @@ class SbiRuntime
void StepLSET(), StepRSET(), StepREDIMP_ERASE(), StepERASE_CLEAR();
void StepARRAYACCESS(), StepBYVAL();
// Alle Opcodes mit einem Operanden
- void StepLOADNC( UINT32 ), StepLOADSC( UINT32 ), StepLOADI( UINT32 );
- void StepARGN( UINT32 ), StepBASED( UINT32 ), StepPAD( UINT32 );
- void StepJUMP( UINT32 ), StepJUMPT( UINT32 );
- void StepJUMPF( UINT32 ), StepONJUMP( UINT32 );
- void StepGOSUB( UINT32 ), StepRETURN( UINT32 );
- void StepTESTFOR( UINT32 ), StepCASETO( UINT32 ), StepERRHDL( UINT32 );
- void StepRESUME( UINT32 ), StepSETCLASS( UINT32 ), StepVBASETCLASS( UINT32 ), StepTESTCLASS( UINT32 ), StepLIB( UINT32 );
+ void StepLOADNC( sal_uInt32 ), StepLOADSC( sal_uInt32 ), StepLOADI( sal_uInt32 );
+ void StepARGN( sal_uInt32 ), StepBASED( sal_uInt32 ), StepPAD( sal_uInt32 );
+ void StepJUMP( sal_uInt32 ), StepJUMPT( sal_uInt32 );
+ void StepJUMPF( sal_uInt32 ), StepONJUMP( sal_uInt32 );
+ void StepGOSUB( sal_uInt32 ), StepRETURN( sal_uInt32 );
+ void StepTESTFOR( sal_uInt32 ), StepCASETO( sal_uInt32 ), StepERRHDL( sal_uInt32 );
+ void StepRESUME( sal_uInt32 ), StepSETCLASS( sal_uInt32 ), StepVBASETCLASS( sal_uInt32 ), StepTESTCLASS( sal_uInt32 ), StepLIB( sal_uInt32 );
bool checkClass_Impl( const SbxVariableRef& refVal, const String& aClass, bool bRaiseErrors, bool bDefault = true );
- void StepCLOSE( UINT32 ), StepPRCHAR( UINT32 ), StepARGTYP( UINT32 );
+ void StepCLOSE( sal_uInt32 ), StepPRCHAR( sal_uInt32 ), StepARGTYP( sal_uInt32 );
// Alle Opcodes mit zwei Operanden
- void StepRTL( UINT32, UINT32 ), StepPUBLIC( UINT32, UINT32 ), StepPUBLIC_P( UINT32, UINT32 );
- void StepPUBLIC_Impl( UINT32, UINT32, bool bUsedForClassModule );
- void StepFIND_Impl( SbxObject* pObj, UINT32 nOp1, UINT32 nOp2, SbError, BOOL bLocal, BOOL bStatic = FALSE );
- void StepFIND( UINT32, UINT32 ), StepELEM( UINT32, UINT32 );
- void StepGLOBAL( UINT32, UINT32 ), StepLOCAL( UINT32, UINT32 );
- void StepPARAM( UINT32, UINT32), StepCREATE( UINT32, UINT32 );
- void StepCALL( UINT32, UINT32 ), StepCALLC( UINT32, UINT32 );
- void StepCASEIS( UINT32, UINT32 ), StepSTMNT( UINT32, UINT32 );
+ void StepRTL( sal_uInt32, sal_uInt32 ), StepPUBLIC( sal_uInt32, sal_uInt32 ), StepPUBLIC_P( sal_uInt32, sal_uInt32 );
+ void StepPUBLIC_Impl( sal_uInt32, sal_uInt32, bool bUsedForClassModule );
+ void StepFIND_Impl( SbxObject* pObj, sal_uInt32 nOp1, sal_uInt32 nOp2, SbError, sal_Bool bLocal, sal_Bool bStatic = sal_False );
+ void StepFIND( sal_uInt32, sal_uInt32 ), StepELEM( sal_uInt32, sal_uInt32 );
+ void StepGLOBAL( sal_uInt32, sal_uInt32 ), StepLOCAL( sal_uInt32, sal_uInt32 );
+ void StepPARAM( sal_uInt32, sal_uInt32), StepCREATE( sal_uInt32, sal_uInt32 );
+ void StepCALL( sal_uInt32, sal_uInt32 ), StepCALLC( sal_uInt32, sal_uInt32 );
+ void StepCASEIS( sal_uInt32, sal_uInt32 ), StepSTMNT( sal_uInt32, sal_uInt32 );
SbxVariable* StepSTATIC_Impl( String& aName, SbxDataType& t );
- void StepOPEN( UINT32, UINT32 ), StepSTATIC( UINT32, UINT32 );
- void StepTCREATE(UINT32,UINT32), StepDCREATE(UINT32,UINT32);
- void StepGLOBAL_P( UINT32, UINT32 ),StepFIND_G( UINT32, UINT32 );
- void StepDCREATE_REDIMP(UINT32,UINT32), StepDCREATE_IMPL(UINT32,UINT32);
- void StepFIND_CM( UINT32, UINT32 );
- void StepFIND_STATIC( UINT32, UINT32 );
- void implCreateFixedString( SbxVariable* pStrVar, UINT32 nOp2 );
+ void StepOPEN( sal_uInt32, sal_uInt32 ), StepSTATIC( sal_uInt32, sal_uInt32 );
+ void StepTCREATE(sal_uInt32,sal_uInt32), StepDCREATE(sal_uInt32,sal_uInt32);
+ void StepGLOBAL_P( sal_uInt32, sal_uInt32 ),StepFIND_G( sal_uInt32, sal_uInt32 );
+ void StepDCREATE_REDIMP(sal_uInt32,sal_uInt32), StepDCREATE_IMPL(sal_uInt32,sal_uInt32);
+ void StepFIND_CM( sal_uInt32, sal_uInt32 );
+ void StepFIND_STATIC( sal_uInt32, sal_uInt32 );
+ void implHandleSbxFlags( SbxVariable* pVar, SbxDataType t, sal_uInt32 nOp2 );
public:
void SetVBAEnabled( bool bEnabled );
- USHORT GetImageFlag( USHORT n ) const;
- USHORT GetBase();
+ sal_uInt16 GetImageFlag( sal_uInt16 n ) const;
+ sal_uInt16 GetBase();
xub_StrLen nLine,nCol1,nCol2; // aktuelle Zeile, Spaltenbereich
SbiRuntime* pNext; // Stack-Chain
- SbiRuntime( SbModule*, SbMethod*, UINT32 );
+ SbiRuntime( SbModule*, SbMethod*, sal_uInt32 );
~SbiRuntime();
void Error( SbError, bool bVBATranslationAlreadyDone = false ); // Fehler setzen, falls != 0
void Error( SbError, const String& ); // Fehler setzen, falls != 0
@@ -445,15 +447,15 @@ public:
void FatalError( SbError, const String& ); // Fehlerbehandlung=Standard, Fehler setzen
static sal_Int32 translateErrorToVba( SbError nError, String& rMsg );
void DumpPCode();
- BOOL Step(); // Einzelschritt (ein Opcode)
- void Stop() { bRun = FALSE; }
- BOOL IsRun() { return bRun; }
- void block( void ) { bBlocked = TRUE; }
- void unblock( void ) { bBlocked = FALSE; }
+ sal_Bool Step(); // Einzelschritt (ein Opcode)
+ void Stop() { bRun = sal_False; }
+ sal_Bool IsRun() { return bRun; }
+ void block( void ) { bBlocked = sal_True; }
+ void unblock( void ) { bBlocked = sal_False; }
SbMethod* GetMethod() { return pMeth; }
SbModule* GetModule() { return pMod; }
- USHORT GetDebugFlags() { return nFlags; }
- void SetDebugFlags( USHORT nFl ) { nFlags = nFl; }
+ sal_uInt16 GetDebugFlags() { return nFlags; }
+ void SetDebugFlags( sal_uInt16 nFl ) { nFlags = nFl; }
SbMethod* GetCaller();
SbxArray* GetLocals();
SbxArray* GetParams();
@@ -487,12 +489,12 @@ StarBASIC* GetCurrentBasic( StarBASIC* pRTBasic );
// no DDE functionality, no DLLCALL) in basic because
// of portal "virtual" users (portal user != UNIX user)
// (Implemented in iosys.cxx)
-BOOL needSecurityRestrictions( void );
+sal_Bool needSecurityRestrictions( void );
-// Returns TRUE if UNO is available, otherwise the old
+// Returns sal_True if UNO is available, otherwise the old
// file system implementation has to be used
// (Implemented in iosys.cxx)
-BOOL hasUno( void );
+sal_Bool hasUno( void );
// Converts possibly relative paths to absolute paths
// according to the setting done by ChDir/ChDrive
diff --git a/basic/source/inc/sbcomp.hxx b/basic/source/inc/sbcomp.hxx
index 2918e67880f0..2918e67880f0 100644..100755
--- a/basic/source/inc/sbcomp.hxx
+++ b/basic/source/inc/sbcomp.hxx
diff --git a/basic/source/inc/sbjsmeth.hxx b/basic/source/inc/sbjsmeth.hxx
index f2cc8a3d3865..f2cc8a3d3865 100644..100755
--- a/basic/source/inc/sbjsmeth.hxx
+++ b/basic/source/inc/sbjsmeth.hxx
diff --git a/basic/source/inc/sbjsmod.hxx b/basic/source/inc/sbjsmod.hxx
index b3aa275aec0d..55091dc681c5 100644..100755
--- a/basic/source/inc/sbjsmod.hxx
+++ b/basic/source/inc/sbjsmod.hxx
@@ -37,8 +37,8 @@
class SbJScriptModule : public SbModule
{
- virtual BOOL LoadData( SvStream&, USHORT );
- virtual BOOL StoreData( SvStream& ) const;
+ virtual sal_Bool LoadData( SvStream&, sal_uInt16 );
+ virtual sal_Bool StoreData( SvStream& ) const;
public:
SBX_DECL_PERSIST_NODATA(SBXCR_SBX,SBXID_JSCRIPTMOD,1);
TYPEINFO();
diff --git a/basic/source/inc/sbtrace.hxx b/basic/source/inc/sbtrace.hxx
new file mode 100755
index 000000000000..50e344fb63d2
--- /dev/null
+++ b/basic/source/inc/sbtrace.hxx
@@ -0,0 +1,44 @@
+/*************************************************************************
+ *
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ *
+ * Copyright 2000, 2010 Oracle and/or its affiliates.
+ *
+ * OpenOffice.org - a multi-platform office productivity suite
+ *
+ * This file is part of OpenOffice.org.
+ *
+ * OpenOffice.org is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License version 3
+ * only, as published by the Free Software Foundation.
+ *
+ * OpenOffice.org is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Lesser General Public License version 3 for more details
+ * (a copy is included in the LICENSE file that accompanied this code).
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * version 3 along with OpenOffice.org. If not, see
+ * <http://www.openoffice.org/license.html>
+ * for a copy of the LGPLv3 License.
+ *
+ ************************************************************************/
+
+#ifndef _SBTRACE_HXX
+#define _SBTRACE_HXX
+
+//#define DBG_TRACE_BASIC
+
+#ifdef DBG_TRACE_BASIC
+void dbg_InitTrace( void );
+void dbg_DeInitTrace( void );
+void dbg_traceStep( SbModule* pModule, UINT32 nPC, INT32 nCallLvl );
+void dbg_traceNotifyCall( SbModule* pModule, SbMethod* pMethod, INT32 nCallLvl, bool bLeave = false );
+void dbg_traceNotifyError( SbError nTraceErr, const String& aTraceErrMsg, bool bTraceErrHandled, INT32 nCallLvl );
+void dbg_RegisterTraceTextForPC( SbModule* pModule, UINT32 nPC,
+ const String& aTraceStr_STMNT, const String& aTraceStr_PCode );
+void RTL_Impl_TraceCommand( StarBASIC* pBasic, SbxArray& rPar, BOOL bWrite );
+#endif
+
+#endif
diff --git a/basic/source/inc/sbunoobj.hxx b/basic/source/inc/sbunoobj.hxx
index faf913229ad3..5905f7f4640f 100644..100755
--- a/basic/source/inc/sbunoobj.hxx
+++ b/basic/source/inc/sbunoobj.hxx
@@ -52,8 +52,8 @@ class SbUnoObject: public SbxObject
::com::sun::star::uno::Reference< ::com::sun::star::script::XInvocation > mxInvocation;
::com::sun::star::uno::Reference< ::com::sun::star::beans::XExactName > mxExactName;
::com::sun::star::uno::Reference< ::com::sun::star::beans::XExactName > mxExactNameInvocation;
- BOOL bNeedIntrospection;
- BOOL bIgnoreNativeCOMObjectMembers;
+ sal_Bool bNeedIntrospection;
+ sal_Bool bNativeCOMObject;
::com::sun::star::uno::Any maTmpUnoObj; // Only to save obj for doIntrospection!
// Hilfs-Methode zum Anlegen der dbg_-Properties
@@ -85,17 +85,22 @@ public:
::com::sun::star::uno::Reference< ::com::sun::star::script::XInvocation > getInvocation( void ) { return mxInvocation; }
void SFX_NOTIFY( SfxBroadcaster&, const TypeId&, const SfxHint& rHint, const TypeId& );
+
+ bool isNativeCOMObject( void )
+ { return bNativeCOMObject; }
};
SV_DECL_IMPL_REF(SbUnoObject);
// #67781 Rueckgabewerte der Uno-Methoden loeschen
void clearUnoMethods( void );
+void clearUnoMethodsForBasic( StarBASIC* pBasic );
class SbUnoMethod : public SbxMethod
{
friend class SbUnoObject;
friend void clearUnoMethods( void );
+ friend void clearUnoMethodsForBasic( StarBASIC* pBasic );
::com::sun::star::uno::Reference< ::com::sun::star::reflection::XIdlMethod > m_xUnoMethod;
::com::sun::star::uno::Sequence< ::com::sun::star::reflection::ParamInfo >* pParamInfoSeq;
@@ -104,13 +109,15 @@ class SbUnoMethod : public SbxMethod
SbUnoMethod* pPrev;
SbUnoMethod* pNext;
- bool mbInvocation; // Method is based on invocation
+ bool mbInvocation; // Method is based on invocation
+ bool mbDirectInvocation; // Method should be used with XDirectInvocation interface
public:
TYPEINFO();
SbUnoMethod( const String& aName_, SbxDataType eSbxType, ::com::sun::star::uno::Reference< ::com::sun::star::reflection::XIdlMethod > xUnoMethod_,
- bool bInvocation );
+ bool bInvocation,
+ bool bDirect = false );
virtual ~SbUnoMethod();
virtual SbxInfo* GetInfo();
@@ -118,6 +125,8 @@ public:
bool isInvocationBased( void )
{ return mbInvocation; }
+ bool needsDirectInvocation( void )
+ { return mbDirectInvocation; }
};
@@ -127,7 +136,7 @@ class SbUnoProperty : public SbxProperty
// Daten der Uno-Property
::com::sun::star::beans::Property aUnoProp;
- INT32 nId;
+ sal_Int32 nId;
bool mbInvocation; // Property is based on invocation
@@ -135,7 +144,7 @@ class SbUnoProperty : public SbxProperty
public:
TYPEINFO();
SbUnoProperty( const String& aName_, SbxDataType eSbxType,
- const ::com::sun::star::beans::Property& aUnoProp_, INT32 nId_, bool bInvocation );
+ const ::com::sun::star::beans::Property& aUnoProp_, sal_Int32 nId_, bool bInvocation );
bool isInvocationBased( void )
{ return mbInvocation; }
@@ -145,7 +154,7 @@ public:
class SbUnoFactory : public SbxFactory
{
public:
- virtual SbxBase* Create( UINT16 nSbxId, UINT32 = SBXCR_SBX );
+ virtual SbxBase* Create( sal_uInt16 nSbxId, sal_uInt32 = SBXCR_SBX );
virtual SbxObject* CreateObject( const String& );
};
@@ -284,15 +293,18 @@ public:
class StarBASIC;
// Impl-Methoden fuer RTL
-void RTL_Impl_CreateUnoStruct( StarBASIC* pBasic, SbxArray& rPar, BOOL bWrite );
-void RTL_Impl_CreateUnoService( StarBASIC* pBasic, SbxArray& rPar, BOOL bWrite );
-void RTL_Impl_CreateUnoServiceWithArguments( StarBASIC* pBasic, SbxArray& rPar, BOOL bWrite );
-void RTL_Impl_CreateUnoValue( StarBASIC* pBasic, SbxArray& rPar, BOOL bWrite );
-void RTL_Impl_GetProcessServiceManager( StarBASIC* pBasic, SbxArray& rPar, BOOL bWrite );
-void RTL_Impl_HasInterfaces( StarBASIC* pBasic, SbxArray& rPar, BOOL bWrite );
-void RTL_Impl_IsUnoStruct( StarBASIC* pBasic, SbxArray& rPar, BOOL bWrite );
-void RTL_Impl_EqualUnoObjects( StarBASIC* pBasic, SbxArray& rPar, BOOL bWrite );
-void RTL_Impl_GetDefaultContext( StarBASIC* pBasic, SbxArray& rPar, BOOL bWrite );
+void RTL_Impl_CreateUnoStruct( StarBASIC* pBasic, SbxArray& rPar, sal_Bool bWrite );
+void RTL_Impl_CreateUnoService( StarBASIC* pBasic, SbxArray& rPar, sal_Bool bWrite );
+void RTL_Impl_CreateUnoServiceWithArguments( StarBASIC* pBasic, SbxArray& rPar, sal_Bool bWrite );
+void RTL_Impl_CreateUnoValue( StarBASIC* pBasic, SbxArray& rPar, sal_Bool bWrite );
+void RTL_Impl_GetProcessServiceManager( StarBASIC* pBasic, SbxArray& rPar, sal_Bool bWrite );
+void RTL_Impl_HasInterfaces( StarBASIC* pBasic, SbxArray& rPar, sal_Bool bWrite );
+void RTL_Impl_IsUnoStruct( StarBASIC* pBasic, SbxArray& rPar, sal_Bool bWrite );
+void RTL_Impl_EqualUnoObjects( StarBASIC* pBasic, SbxArray& rPar, sal_Bool bWrite );
+void RTL_Impl_GetDefaultContext( StarBASIC* pBasic, SbxArray& rPar, sal_Bool bWrite );
+
+void disposeComVariablesForBasic( StarBASIC* pBasic );
+void clearNativeObjectWrapperVector( void );
//========================================================================
@@ -309,8 +321,8 @@ class BasicCollection : public SbxObject
virtual ~BasicCollection();
virtual void SFX_NOTIFY( SfxBroadcaster& rBC, const TypeId& rBCType,
const SfxHint& rHint, const TypeId& rHintType );
- INT32 implGetIndex( SbxVariable* pIndexVar );
- INT32 implGetIndexForName( const String& rName );
+ sal_Int32 implGetIndex( SbxVariable* pIndexVar );
+ sal_Int32 implGetIndexForName( const String& rName );
void CollAdd( SbxArray* pPar_ );
void CollItem( SbxArray* pPar_ );
void CollRemove( SbxArray* pPar_ );
diff --git a/basic/source/inc/scriptcont.hxx b/basic/source/inc/scriptcont.hxx
index f7f948bd0b31..0966c258380a 100644..100755
--- a/basic/source/inc/scriptcont.hxx
+++ b/basic/source/inc/scriptcont.hxx
@@ -44,6 +44,7 @@ namespace basic
class SfxScriptLibraryContainer : public SfxLibraryContainer, public OldBasicPassword
{
::rtl::OUString maScriptLanguage;
+ ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess > mxCodeNameAccess;
// Methods to distinguish between deffirent library types
virtual SfxLibrary* SAL_CALL implCreateLibrary( const ::rtl::OUString& aName );
diff --git a/basic/source/inc/stdobj.hxx b/basic/source/inc/stdobj.hxx
index 9087b81e3028..7abaf47492f1 100644..100755
--- a/basic/source/inc/stdobj.hxx
+++ b/basic/source/inc/stdobj.hxx
@@ -46,7 +46,7 @@ class SbiStdObject : public SbxObject
public:
SbiStdObject( const String&, StarBASIC* );
virtual SbxVariable* Find( const String&, SbxClassType );
- virtual void SetModified( BOOL );
+ virtual void SetModified( sal_Bool );
};
#endif
diff --git a/basic/source/inc/expr.hxx b/basic/source/inc/expr.hxx
index 1819877f5c43..0ae218d14c18 100644..100755
--- a/basic/source/inc/expr.hxx
+++ b/basic/source/inc/expr.hxx
@@ -99,7 +99,7 @@ class SbiExprNode { // Operatoren (und Operanden)
friend class SbiExpression;
friend class SbiConstExpression;
union {
- USHORT nTypeStrId; // gepoolter String-ID, #i59791/#i45570 Now only for TypeOf
+ sal_uInt16 nTypeStrId; // gepoolter String-ID, #i59791/#i45570 Now only for TypeOf
double nVal; // numerischer Wert
SbVar aVar; // oder Variable
};
@@ -111,19 +111,19 @@ class SbiExprNode { // Operatoren (und Operanden)
SbiNodeType eNodeType; // Art des Nodes
SbxDataType eType; // aktueller Datentyp
SbiToken eTok; // Token des Operators
- BOOL bComposite; // TRUE: Zusammengesetzter Ausdruck
- BOOL bError; // TRUE: Fehlerhaft
+ sal_Bool bComposite; // sal_True: Zusammengesetzter Ausdruck
+ sal_Bool bError; // sal_True: Fehlerhaft
void FoldConstants(); // Constant Folding durchfuehren
void CollectBits(); // Umwandeln von Zahlen in Strings
- BOOL IsOperand() // TRUE, wenn Operand
- { return BOOL( eNodeType != SbxNODE && eNodeType != SbxTYPEOF && eNodeType != SbxNEW ); }
- BOOL IsTypeOf()
- { return BOOL( eNodeType == SbxTYPEOF ); }
- BOOL IsNew()
- { return BOOL( eNodeType == SbxNEW ); }
- BOOL IsNumber(); // TRUE bei Zahlen
- BOOL IsString(); // TRUE bei Strings
- BOOL IsLvalue(); // TRUE, falls als Lvalue verwendbar
+ sal_Bool IsOperand() // sal_True, wenn Operand
+ { return sal_Bool( eNodeType != SbxNODE && eNodeType != SbxTYPEOF && eNodeType != SbxNEW ); }
+ sal_Bool IsTypeOf()
+ { return sal_Bool( eNodeType == SbxTYPEOF ); }
+ sal_Bool IsNew()
+ { return sal_Bool( eNodeType == SbxNEW ); }
+ sal_Bool IsNumber(); // sal_True bei Zahlen
+ sal_Bool IsString(); // sal_True bei Strings
+ sal_Bool IsLvalue(); // sal_True, falls als Lvalue verwendbar
void GenElement( SbiOpcode ); // Element
void BaseInit( SbiParser* p ); // Hilfsfunktion fuer Ctor, AB 17.12.95
public:
@@ -132,15 +132,15 @@ public:
SbiExprNode( SbiParser*, const String& );
SbiExprNode( SbiParser*, const SbiSymDef&, SbxDataType, SbiExprList* = NULL );
SbiExprNode( SbiParser*, SbiExprNode*, SbiToken, SbiExprNode* );
- SbiExprNode( SbiParser*, SbiExprNode*, USHORT ); // #120061 TypeOf
- SbiExprNode( SbiParser*, USHORT ); // new <type>
+ SbiExprNode( SbiParser*, SbiExprNode*, sal_uInt16 ); // #120061 TypeOf
+ SbiExprNode( SbiParser*, sal_uInt16 ); // new <type>
virtual ~SbiExprNode();
- BOOL IsValid() { return BOOL( !bError ); }
- BOOL IsConstant() // TRUE bei konstantem Operanden
- { return BOOL( eNodeType == SbxSTRVAL || eNodeType == SbxNUMVAL ); }
- BOOL IsIntConst(); // TRUE bei Integer-Konstanten
- BOOL IsVariable(); // TRUE, wenn Variable
+ sal_Bool IsValid() { return sal_Bool( !bError ); }
+ sal_Bool IsConstant() // sal_True bei konstantem Operanden
+ { return sal_Bool( eNodeType == SbxSTRVAL || eNodeType == SbxNUMVAL ); }
+ sal_Bool IsIntConst(); // sal_True bei Integer-Konstanten
+ sal_Bool IsVariable(); // sal_True, wenn Variable
SbiExprNode* GetWithParent() { return pWithParent; }
void SetWithParent( SbiExprNode* p ) { pWithParent = p; }
@@ -173,11 +173,11 @@ protected:
SbiExprNode* pExpr; // Der Expression-Baum
SbiExprType eCurExpr; // Art des Ausdrucks
SbiExprMode m_eMode; // Expression context
- BOOL bBased; // TRUE: einfacher DIM-Teil (+BASE)
- BOOL bError; // TRUE: Fehler
- BOOL bByVal; // TRUE: ByVal-Parameter
- BOOL bBracket; // TRUE: Parameter list with brackets
- USHORT nParenLevel;
+ sal_Bool bBased; // sal_True: einfacher DIM-Teil (+BASE)
+ sal_Bool bError; // sal_True: Fehler
+ sal_Bool bByVal; // sal_True: ByVal-Parameter
+ sal_Bool bBracket; // sal_True: Parameter list with brackets
+ sal_uInt16 nParenLevel;
SbiExprNode* Term( const KeywordSymbolInfo* pKeywordSymbolInfo = NULL );
SbiExprNode* ObjTerm( SbiSymDef& );
SbiExprNode* Operand( bool bUsedForTypeOf = false );
@@ -206,16 +206,16 @@ public:
SbiExpression( SbiParser*, SbiToken ); // Spezial-Expr mit Spezial-Tokens
~SbiExpression();
String& GetName() { return aArgName; }
- void SetBased() { bBased = TRUE; }
- BOOL IsBased() { return bBased; }
- void SetByVal() { bByVal = TRUE; }
- BOOL IsByVal() { return bByVal; }
- BOOL IsBracket() { return bBracket; }
- BOOL IsValid() { return pExpr->IsValid(); }
- BOOL IsConstant() { return pExpr->IsConstant(); }
- BOOL IsVariable() { return pExpr->IsVariable(); }
- BOOL IsLvalue() { return pExpr->IsLvalue(); }
- BOOL IsIntConstant() { return pExpr->IsIntConst(); }
+ void SetBased() { bBased = sal_True; }
+ sal_Bool IsBased() { return bBased; }
+ void SetByVal() { bByVal = sal_True; }
+ sal_Bool IsByVal() { return bByVal; }
+ sal_Bool IsBracket() { return bBracket; }
+ sal_Bool IsValid() { return pExpr->IsValid(); }
+ sal_Bool IsConstant() { return pExpr->IsConstant(); }
+ sal_Bool IsVariable() { return pExpr->IsVariable(); }
+ sal_Bool IsLvalue() { return pExpr->IsLvalue(); }
+ sal_Bool IsIntConstant() { return pExpr->IsIntConst(); }
const String& GetString() { return pExpr->GetString(); }
SbiSymDef* GetVar() { return pExpr->GetVar(); }
SbiSymDef* GetRealVar() { return pExpr->GetRealVar(); }
@@ -243,31 +243,31 @@ protected:
SbiExpression* pFirst; // Expressions
short nExpr; // Anzahl Expressions
short nDim; // Anzahl Dimensionen
- BOOL bError; // TRUE: Fehler
- BOOL bBracket; // TRUE: Klammern
+ sal_Bool bError; // sal_True: Fehler
+ sal_Bool bBracket; // sal_True: Klammern
public:
SbiExprList( SbiParser* );
virtual ~SbiExprList();
- BOOL IsBracket() { return bBracket; }
- BOOL IsValid() { return BOOL( !bError ); }
+ sal_Bool IsBracket() { return bBracket; }
+ sal_Bool IsValid() { return sal_Bool( !bError ); }
short GetSize() { return nExpr; }
short GetDims() { return nDim; }
SbiExpression* Get( short );
- BOOL Test( const SbiProcDef& ); // Parameter-Checks
+ sal_Bool Test( const SbiProcDef& ); // Parameter-Checks
void Gen(); // Code-Erzeugung
void addExpression( SbiExpression* pExpr );
};
class SbiParameters : public SbiExprList {
public:
- SbiParameters( SbiParser*, BOOL bConst = FALSE, BOOL bPar = TRUE);// parsender Ctor
+ SbiParameters( SbiParser*, sal_Bool bConst = sal_False, sal_Bool bPar = sal_True);// parsender Ctor
};
class SbiDimList : public SbiExprList {
- BOOL bConst; // TRUE: Alles sind Integer-Konstanten
+ sal_Bool bConst; // sal_True: Alles sind Integer-Konstanten
public:
SbiDimList( SbiParser* ); // Parsender Ctor
- BOOL IsConstant() { return bConst; }
+ sal_Bool IsConstant() { return bConst; }
};
#endif
diff --git a/basic/source/inc/filefmt.hxx b/basic/source/inc/filefmt.hxx
index 0319daf7261b..087581617297 100644..100755
--- a/basic/source/inc/filefmt.hxx
+++ b/basic/source/inc/filefmt.hxx
@@ -58,9 +58,9 @@ class SvStream;
// Diese Records enthalten wiederum weitere Records. Jeder Record hat
// den folgenden Header:
// UINT16 Kennung
// UINT32 Laenge des Records ohne Header
// UINT16 Anzahl Unterelemente
// Alle Datei-Offsets in Records sind relativ zum Start des Moduls!
@@ -85,33 +85,33 @@ class SvStream;
#endif
// Ein Library Record enthaelt nur Module Records
// UINT16 Kennung BL
// UINT32 Laenge des Records
// UINT16 Anzahl Module
// Ein Modul-Record enthaelt alle anderen Recordtypen
-// UINT16 Kennung BM
-// UINT32 Laenge des Records
-// UINT16 1
+// sal_uInt16 Kennung BM
+// sal_uInt32 Laenge des Records
+// sal_uInt16 1
// Daten:
// UINT32 Versionsnummer
// UINT32 Zeichensatz
// UINT32 Startadresse Initialisierungscode
// UINT32 Startadresse Sub Main
// UINT32 Reserviert
// UINT32 Reserviert
// Modulname, Kommentar und Quellcode:
// UINT16 Kennung MN, MC oder SC
// UINT32 Laenge des Records
// UINT16 1
// Daten:
// String-Instanz
// P-Code:
-// UINT16 Kennung PC
-// UINT32 Laenge des Records
-// UINT16 1
+// sal_uInt16 Kennung PC
+// sal_uInt32 Laenge des Records
+// sal_uInt16 1
// Daten:
// Der P-Code als Bytesack
@@ -119,62 +119,62 @@ class SvStream;
// Verweise auf diese Strings sind in Form eines Indexes in diesen Pool.
// Liste aller Publics:
// UINT16 Kennung PU oder Pu
// UINT32 Laenge des Records
// UINT16 Anzahl der Publics
// Daten fuer jeden Public-Eintrag:
// UINT16 String-Index
// UINT32 Startadresse im P-Code-Image (UINT16 fuer alte Publics)
// UINT16 Datentyp des Returnwertes (ab Version 2)
// Verzeichnis der Symbol-Tabellen:
// UINT16 Kennung SP
// UINT32 Laenge des Records
// UINT16 Anzahl der Symboltabellen
// Daten fuer jede Symboltabelle:
// UINT16 Stringindex des Namens
// UINT16 Anzahl Symbole
// UINT16 Scope-Kennung
// Symboltabelle:
// UINT16 Kennung SY
// UINT32 Laenge des Records
// UINT16 Anzahl der Symbole
// Daten:
// UINT16 Stringindex des Namens
// UINT16 Anzahl Symbole
// Daten fuer jedes Symbol:
// UINT16 Stringindex des Namens
// UINT16 Datentyp
// UINT16 Laenge bei STRING*n-Symbolen (0x8000: STATIC-Variable)
// Stringpool:
// UINT16 Kennung ST
// UINT32 Laenge des Records
// UINT16 Anzahl der Strings
// Daten fuer jeden String:
// UINT32 Offset in den Block aller Strings
// Danach folgt der Block aller Strings, die dort als ASCIIZ-Strings liegen.
// Line Ranges:
// UINT16 Kennung LR
// UINT32 Laenge des Records
// UINT16 Anzahl der Strings
// Daten fuer jedes Public:
-// UINT16 1. Zeile (Sub XXX)
-// UINT16 2. Zeile (End Sub)
+// sal_uInt16 1. Zeile (Sub XXX)
+// sal_uInt16 2. Zeile (End Sub)
// SBX-Objekte:
-// UINT16 Anzahl Objekte
+// sal_uInt16 Anzahl Objekte
// .... Objektdaten
////////////////////////////////////////////////////////////////////////////
// Service-Routinen (in IMAGE.CXX)
-BOOL SbGood( SvStream& r );
-ULONG SbOpenRecord( SvStream&, UINT16 nSignature, UINT16 nElem );
-void SbCloseRecord( SvStream&, ULONG );
+sal_Bool SbGood( SvStream& r );
+sal_uIntPtr SbOpenRecord( SvStream&, sal_uInt16 nSignature, sal_uInt16 nElem );
+void SbCloseRecord( SvStream&, sal_uIntPtr );
#endif
@@ -58,9 +58,9 @@ class SvStream;
// Diese Records enthalten wiederum weitere Records. Jeder Record hat
// den folgenden Header:
-// UINT16 Kennung
-// UINT32 Laenge des Records ohne Header
-// UINT16 Anzahl Unterelemente
+// sal_uInt16 Kennung
+// sal_uInt32 Laenge des Records ohne Header
+// sal_uInt16 Anzahl Unterelemente
// Alle Datei-Offsets in Records sind relativ zum Start des Moduls!
@@ -85,33 +85,33 @@ class SvStream;
#endif
// Ein Library Record enthaelt nur Module Records
-// UINT16 Kennung BL
-// UINT32 Laenge des Records
-// UINT16 Anzahl Module
+// sal_uInt16 Kennung BL
+// sal_uInt32 Laenge des Records
+// sal_uInt16 Anzahl Module
// Ein Modul-Record enthaelt alle anderen Recordtypen
@@ -85,33 +85,33 @@ class SvStream;
// Daten:
-// UINT32 Versionsnummer
-// UINT32 Zeichensatz
-// UINT32 Startadresse Initialisierungscode
-// UINT32 Startadresse Sub Main
-// UINT32 Reserviert
-// UINT32 Reserviert
+// sal_uInt32 Versionsnummer
+// sal_uInt32 Zeichensatz
+// sal_uInt32 Startadresse Initialisierungscode
+// sal_uInt32 Startadresse Sub Main
+// sal_uInt32 Reserviert
+// sal_uInt32 Reserviert
// Modulname, Kommentar und Quellcode:
@@ -85,33 +85,33 @@ class SvStream;
// Modulname, Kommentar und Quellcode:
-// UINT16 Kennung MN, MC oder SC
-// UINT32 Laenge des Records
-// UINT16 1
+// sal_uInt16 Kennung MN, MC oder SC
+// sal_uInt32 Laenge des Records
+// sal_uInt16 1
// Daten:
// String-Instanz
@@ -119,62 +119,62 @@ class SvStream;
// Verweise auf diese Strings sind in Form eines Indexes in diesen Pool.
// Liste aller Publics:
-// UINT16 Kennung PU oder Pu
-// UINT32 Laenge des Records
-// UINT16 Anzahl der Publics
+// sal_uInt16 Kennung PU oder Pu
+// sal_uInt32 Laenge des Records
+// sal_uInt16 Anzahl der Publics
// Daten fuer jeden Public-Eintrag:
@@ -119,62 +119,62 @@ class SvStream;
// Daten fuer jeden Public-Eintrag:
-// UINT16 String-Index
-// UINT32 Startadresse im P-Code-Image (UINT16 fuer alte Publics)
-// UINT16 Datentyp des Returnwertes (ab Version 2)
+// sal_uInt16 String-Index
+// sal_uInt32 Startadresse im P-Code-Image (sal_uInt16 fuer alte Publics)
+// sal_uInt16 Datentyp des Returnwertes (ab Version 2)
// Verzeichnis der Symbol-Tabellen:
@@ -119,62 +119,62 @@ class SvStream;
// Verzeichnis der Symbol-Tabellen:
-// UINT16 Kennung SP
-// UINT32 Laenge des Records
-// UINT16 Anzahl der Symboltabellen
+// sal_uInt16 Kennung SP
+// sal_uInt32 Laenge des Records
+// sal_uInt16 Anzahl der Symboltabellen
// Daten fuer jede Symboltabelle:
@@ -119,62 +119,62 @@ class SvStream;
// Daten fuer jede Symboltabelle:
-// UINT16 Stringindex des Namens
-// UINT16 Anzahl Symbole
-// UINT16 Scope-Kennung
+// sal_uInt16 Stringindex des Namens
+// sal_uInt16 Anzahl Symbole
+// sal_uInt16 Scope-Kennung
// Symboltabelle:
@@ -119,62 +119,62 @@ class SvStream;
// Symboltabelle:
-// UINT16 Kennung SY
-// UINT32 Laenge des Records
-// UINT16 Anzahl der Symbole
+// sal_uInt16 Kennung SY
+// sal_uInt32 Laenge des Records
+// sal_uInt16 Anzahl der Symbole
// Daten:
@@ -119,62 +119,62 @@ class SvStream;
// Daten:
-// UINT16 Stringindex des Namens
-// UINT16 Anzahl Symbole
+// sal_uInt16 Stringindex des Namens
+// sal_uInt16 Anzahl Symbole
// Daten fuer jedes Symbol:
@@ -119,62 +119,62 @@ class SvStream;
// Daten fuer jedes Symbol:
-// UINT16 Stringindex des Namens
-// UINT16 Datentyp
-// UINT16 Laenge bei STRING*n-Symbolen (0x8000: STATIC-Variable)
+// sal_uInt16 Stringindex des Namens
+// sal_uInt16 Datentyp
+// sal_uInt16 Laenge bei STRING*n-Symbolen (0x8000: STATIC-Variable)
// Stringpool:
@@ -119,62 +119,62 @@ class SvStream;
// Stringpool:
-// UINT16 Kennung ST
-// UINT32 Laenge des Records
-// UINT16 Anzahl der Strings
+// sal_uInt16 Kennung ST
+// sal_uInt32 Laenge des Records
+// sal_uInt16 Anzahl der Strings
// Daten fuer jeden String:
@@ -119,62 +119,62 @@ class SvStream;
// Daten fuer jeden String:
-// UINT32 Offset in den Block aller Strings
+// sal_uInt32 Offset in den Block aller Strings
// Danach folgt der Block aller Strings, die dort als ASCIIZ-Strings liegen.
// Line Ranges:
@@ -119,62 +119,62 @@ class SvStream;
// Danach folgt der Block aller Strings, die dort als ASCIIZ-Strings liegen.
// Line Ranges:
-// UINT16 Kennung LR
-// UINT32 Laenge des Records
-// UINT16 Anzahl der Strings
+// sal_uInt16 Kennung LR
+// sal_uInt32 Laenge des Records
+// sal_uInt16 Anzahl der Strings
// Daten fuer jedes Public:
diff --git a/basic/source/inc/image.hxx b/basic/source/inc/image.hxx
index 24a530ed1061..b852ba1e427f 100644..100755
--- a/basic/source/inc/image.hxx
+++ b/basic/source/inc/image.hxx
@@ -43,25 +43,25 @@ class SbiImage {
SbxArrayRef rTypes; // User defined types
SbxArrayRef rEnums; // Enum types
- UINT32* pStringOff; // StringId-Offsets
+ sal_uInt32* pStringOff; // StringId-Offsets
sal_Unicode* pStrings; // StringPool
char* pCode; // Code-Image
char* pLegacyPCode; // Code-Image
- BOOL bError; // TRUE: Fehler
- USHORT nFlags; // Flags (s.u.)
+ sal_Bool bError; // sal_True: Fehler
+ sal_uInt16 nFlags; // Flags (s.u.)
short nStrings; // Anzahl Strings
- UINT32 nStringSize; // Groesse des String-Puffers
- UINT32 nCodeSize; // Groesse des Code-Blocks
- UINT16 nLegacyCodeSize; // Groesse des Code-Blocks
- UINT16 nDimBase; // OPTION BASE-Wert
+ sal_uInt32 nStringSize; // Groesse des String-Puffers
+ sal_uInt32 nCodeSize; // Groesse des Code-Blocks
+ sal_uInt16 nLegacyCodeSize; // Groesse des Code-Blocks
+ sal_uInt16 nDimBase; // OPTION BASE-Wert
rtl_TextEncoding eCharSet; // Zeichensatz fuer Strings
// temporaere Verwaltungs-Variable:
short nStringIdx; // aktueller String-Index
- UINT32 nStringOff; // aktuelle Pos im Stringpuffer
+ sal_uInt32 nStringOff; // aktuelle Pos im Stringpuffer
// Routinen fuer Compiler:
void MakeStrings( short ); // StringPool einrichten
void AddString( const String& );// String zufuegen
- void AddCode( char*, UINT32 ); // Codeblock dazu
+ void AddCode( char*, sal_uInt32 ); // Codeblock dazu
void AddType(SbxObject *); // User-Type mit aufnehmen
void AddEnum(SbxObject *); // Register enum type
@@ -69,35 +69,35 @@ public:
String aName; // Makroname
::rtl::OUString aOUSource; // Quellcode
String aComment; // Kommentar
- BOOL bInit; // TRUE: Init-Code ist gelaufen
- BOOL bFirstInit; // TRUE, wenn das Image das erste mal nach
+ sal_Bool bInit; // sal_True: Init-Code ist gelaufen
+ sal_Bool bFirstInit; // sal_True, wenn das Image das erste mal nach
// dem Compilieren initialisiert wird.
SbiImage();
~SbiImage();
void Clear(); // Inhalt loeschen
- BOOL Load( SvStream&, UINT32& nVer ); // Loads image from stream
+ sal_Bool Load( SvStream&, sal_uInt32& nVer ); // Loads image from stream
// nVer is set to version
// of image
- BOOL Load( SvStream& );
- BOOL Save( SvStream&, UINT32 = B_CURVERSION );
- BOOL IsError() { return bError; }
+ sal_Bool Load( SvStream& );
+ sal_Bool Save( SvStream&, sal_uInt32 = B_CURVERSION );
+ sal_Bool IsError() { return bError; }
const char* GetCode() const { return pCode; }
- UINT32 GetCodeSize() const { return nCodeSize; }
+ sal_uInt32 GetCodeSize() const { return nCodeSize; }
::rtl::OUString& GetSource32() { return aOUSource; }
- USHORT GetBase() const { return nDimBase; }
+ sal_uInt16 GetBase() const { return nDimBase; }
String GetString( short nId ) const;
//const char* GetString( short nId ) const;
const SbxObject* FindType (String aTypeName) const;
SbxArrayRef GetEnums() { return rEnums; }
- void SetFlag( USHORT n ) { nFlags |= n; }
- USHORT GetFlag( USHORT n ) const { return nFlags & n; }
- UINT16 CalcLegacyOffset( INT32 nOffset );
- UINT32 CalcNewOffset( INT16 nOffset );
+ void SetFlag( sal_uInt16 n ) { nFlags |= n; }
+ sal_uInt16 GetFlag( sal_uInt16 n ) const { return nFlags & n; }
+ sal_uInt16 CalcLegacyOffset( sal_Int32 nOffset );
+ sal_uInt32 CalcNewOffset( sal_Int16 nOffset );
void ReleaseLegacyBuffer();
- BOOL ExceedsLegacyLimits();
+ sal_Bool ExceedsLegacyLimits();
};
diff --git a/basic/source/inc/parser.hxx b/basic/source/inc/parser.hxx
index 3db87e49817c..1b58e5d39f0b 100644..100755
--- a/basic/source/inc/parser.hxx
+++ b/basic/source/inc/parser.hxx
@@ -47,24 +47,24 @@ class SbiParser : public SbiTokenizer
SbiProcDef* pProc; // aktuelle Prozedur
SbiExprNode* pWithVar; // aktuelle With-Variable
SbiToken eEndTok; // das Ende-Token
- UINT32 nGblChain; // Chainkette fuer globale DIMs
- BOOL bGblDefs; // TRUE globale Definitionen allgemein
- BOOL bNewGblDefs; // TRUE globale Definitionen vor Sub
- BOOL bSingleLineIf; // TRUE einzeiliges if-Statement
-
- SbiSymDef* VarDecl( SbiDimList**,BOOL,BOOL );// Variablen-Deklaration
- SbiProcDef* ProcDecl(BOOL bDecl);// Prozedur-Deklaration
- void DefStatic( BOOL bPrivate );
- void DefProc( BOOL bStatic, BOOL bPrivate ); // Prozedur einlesen
- void DefVar( SbiOpcode eOp, BOOL bStatic ); // DIM/REDIM einlesen
- void TypeDecl( SbiSymDef&, BOOL bAsNewAlreadyParsed=FALSE ); // AS-Deklaration
+ sal_uInt32 nGblChain; // Chainkette fuer globale DIMs
+ sal_Bool bGblDefs; // sal_True globale Definitionen allgemein
+ sal_Bool bNewGblDefs; // sal_True globale Definitionen vor Sub
+ sal_Bool bSingleLineIf; // sal_True einzeiliges if-Statement
+
+ SbiSymDef* VarDecl( SbiDimList**,sal_Bool,sal_Bool );// Variablen-Deklaration
+ SbiProcDef* ProcDecl(sal_Bool bDecl);// Prozedur-Deklaration
+ void DefStatic( sal_Bool bPrivate );
+ void DefProc( sal_Bool bStatic, sal_Bool bPrivate ); // Prozedur einlesen
+ void DefVar( SbiOpcode eOp, sal_Bool bStatic ); // DIM/REDIM einlesen
+ void TypeDecl( SbiSymDef&, sal_Bool bAsNewAlreadyParsed=sal_False ); // AS-Deklaration
void OpenBlock( SbiToken, SbiExprNode* = NULL ); // Block oeffnen
void CloseBlock(); // Block aufloesen
- BOOL Channel( BOOL=FALSE ); // Kanalnummer parsen
+ sal_Bool Channel( sal_Bool=sal_False ); // Kanalnummer parsen
void StmntBlock( SbiToken ); // Statement-Block abarbeiten
- void DefType( BOOL bPrivate ); // Parse type declaration
- void DefEnum( BOOL bPrivate ); // Parse enum declaration
- void DefDeclare( BOOL bPrivate );
+ void DefType( sal_Bool bPrivate ); // Parse type declaration
+ void DefEnum( sal_Bool bPrivate ); // Parse enum declaration
+ void DefDeclare( sal_Bool bPrivate );
void EnableCompatibility();
public:
SbxArrayRef rTypeArray; // das Type-Array
@@ -79,26 +79,26 @@ public:
SbiSymPool* pPool; // aktueller Pool
SbiExprType eCurExpr; // aktueller Expr-Typ
short nBase; // OPTION BASE-Wert
- BOOL bText; // OPTION COMPARE TEXT
- BOOL bExplicit; // TRUE: OPTION EXPLICIT
- BOOL bClassModule; // TRUE: OPTION ClassModule
+ sal_Bool bText; // OPTION COMPARE TEXT
+ sal_Bool bExplicit; // sal_True: OPTION EXPLICIT
+ sal_Bool bClassModule; // sal_True: OPTION ClassModule
StringVector aIfaceVector; // Holds all interfaces implemented by a class module
StringVector aRequiredTypes; // Types used in Dim As New <type> outside subs
SbxDataType eDefTypes[26]; // DEFxxx-Datentypen
SbiParser( StarBASIC*, SbModule* );
- BOOL Parse(); // die Aktion
+ sal_Bool Parse(); // die Aktion
SbiExprNode* GetWithVar(); // Innerste With-Variable liefern
// AB 31.3.1996, Symbol in Runtime-Library suchen
SbiSymDef* CheckRTLForSym( const String& rSym, SbxDataType eType );
void AddConstants( void );
- BOOL HasGlobalCode(); // Globaler Code definiert?
+ sal_Bool HasGlobalCode(); // Globaler Code definiert?
- BOOL TestToken( SbiToken ); // bestimmtes TOken?
- BOOL TestSymbol( BOOL=FALSE ); // Symbol?
- BOOL TestComma(); // Komma oder EOLN?
+ sal_Bool TestToken( SbiToken ); // bestimmtes TOken?
+ sal_Bool TestSymbol( sal_Bool=sal_False ); // Symbol?
+ sal_Bool TestComma(); // Komma oder EOLN?
void TestEoln(); // EOLN?
void Symbol( const KeywordSymbolInfo* pKeywordSymbolInfo = NULL ); // Let oder Call
diff --git a/basic/source/inc/sbintern.hxx b/basic/source/inc/sbintern.hxx
index 7003b5a0a1bb..34d08f6e8c21 100644..100755
--- a/basic/source/inc/sbintern.hxx
+++ b/basic/source/inc/sbintern.hxx
@@ -47,7 +47,7 @@ class SbModule;
class SbiFactory : public SbxFactory
{
public:
- virtual SbxBase* Create( UINT16 nSbxId, UINT32 = SBXCR_SBX );
+ virtual SbxBase* Create( sal_uInt16 nSbxId, sal_uInt32 = SBXCR_SBX );
virtual SbxObject* CreateObject( const String& );
};
@@ -80,7 +80,7 @@ public:
void AddClassModule( SbModule* pClassModule );
void RemoveClassModule( SbModule* pClassModule );
- virtual SbxBase* Create( UINT16 nSbxId, UINT32 = SBXCR_SBX );
+ virtual SbxBase* Create( sal_uInt16 nSbxId, sal_uInt32 = SBXCR_SBX );
virtual SbxObject* CreateObject( const String& );
SbModule* FindClass( const String& rClassName );
@@ -118,14 +118,14 @@ struct SbiGlobals
SbError nCode; // aktueller Fehlercode
xub_StrLen nLine; // aktuelle Zeile
xub_StrLen nCol1,nCol2; // aktuelle Spalten (von,bis)
- BOOL bCompiler; // Flag fuer Compiler-Error
- BOOL bGlobalInitErr; // Beim GlobalInit trat ein Compiler-Fehler auf
- BOOL bRunInit; // TRUE, wenn RunInit vom Basic aktiv ist
+ sal_Bool bCompiler; // Flag fuer Compiler-Error
+ sal_Bool bGlobalInitErr; // Beim GlobalInit trat ein Compiler-Fehler auf
+ sal_Bool bRunInit; // sal_True, wenn RunInit vom Basic aktiv ist
String aErrMsg; // Puffer fuer GetErrorText()
SbLanguageMode eLanguageMode; // Flag fuer Visual-Basic-Script-Modus
SbErrorStack* pErrStack; // Stack fuer die im Fehlerfall abgebaute SbiRuntime Kette
::utl::TransliterationWrapper* pTransliterationWrapper; // For StrComp
- BOOL bBlockCompilerError;
+ sal_Bool bBlockCompilerError;
BasicManager* pAppBasMgr;
StarBASIC* pMSOMacroRuntimLib; // Lib containing MSO Macro Runtime API entry symbols
diff --git a/basic/source/inc/scanner.hxx b/basic/source/inc/scanner.hxx
index 5a6a29c1a9c7..5abfc1efdd3c 100644..100755
--- a/basic/source/inc/scanner.hxx
+++ b/basic/source/inc/scanner.hxx
@@ -57,33 +57,33 @@ protected:
short nCol; // aktuelle Spaltennummer
short nErrors; // Anzahl Fehler
short nColLock; // Lock-Zaehler fuer Col1
- INT32 nBufPos; // aktuelle Buffer-Pos
- USHORT nLine; // aktuelle Zeile
- USHORT nCol1, nCol2; // aktuelle 1. und 2. Spalte
- BOOL bSymbol; // TRUE: Symbol gescannt
- BOOL bNumber; // TRUE: Zahl gescannt
- BOOL bSpaces; // TRUE: Whitespace vor Token
- BOOL bErrors; // TRUE: Fehler generieren
- BOOL bAbort; // TRUE: abbrechen
- BOOL bHash; // TRUE: # eingelesen
- BOOL bError; // TRUE: Fehler generieren
- BOOL bUsedForHilite; // TRUE: Nutzung fuer Highlighting
- BOOL bCompatible; // TRUE: OPTION Compatibl
- BOOL bVBASupportOn; // TRUE: OPTION VBASupport 1 otherwise default False
- BOOL bPrevLineExtentsComment; // TRUE: Previous line is comment and ends on "... _"
+ sal_Int32 nBufPos; // aktuelle Buffer-Pos
+ sal_uInt16 nLine; // aktuelle Zeile
+ sal_uInt16 nCol1, nCol2; // aktuelle 1. und 2. Spalte
+ sal_Bool bSymbol; // sal_True: Symbol gescannt
+ sal_Bool bNumber; // sal_True: Zahl gescannt
+ sal_Bool bSpaces; // sal_True: Whitespace vor Token
+ sal_Bool bErrors; // sal_True: Fehler generieren
+ sal_Bool bAbort; // sal_True: abbrechen
+ sal_Bool bHash; // sal_True: # eingelesen
+ sal_Bool bError; // sal_True: Fehler generieren
+ sal_Bool bUsedForHilite; // sal_True: Nutzung fuer Highlighting
+ sal_Bool bCompatible; // sal_True: OPTION Compatibl
+ sal_Bool bVBASupportOn; // sal_True: OPTION VBASupport 1 otherwise default False
+ sal_Bool bPrevLineExtentsComment; // sal_True: Previous line is comment and ends on "... _"
void GenError( SbError );
public:
SbiScanner( const ::rtl::OUString&, StarBASIC* = NULL );
~SbiScanner();
- void EnableErrors() { bError = FALSE; }
- BOOL IsHash() { return bHash; }
- BOOL IsCompatible() { return bCompatible; }
+ void EnableErrors() { bError = sal_False; }
+ sal_Bool IsHash() { return bHash; }
+ sal_Bool IsCompatible() { return bCompatible; }
void SetCompatible( bool b ) { bCompatible = b; } // #118206
- BOOL IsVBASupportOn() { return bVBASupportOn; }
+ sal_Bool IsVBASupportOn() { return bVBASupportOn; }
void SetVBASupportOn( bool b ) { bVBASupportOn = b; }
- BOOL WhiteSpace() { return bSpaces; }
+ sal_Bool WhiteSpace() { return bSpaces; }
short GetErrors() { return nErrors; }
short GetLine() { return nLine; }
short GetCol1() { return nCol1; }
@@ -94,9 +94,9 @@ public:
void RestoreLine(void) { pLine = pSaveLine; }
void LockColumn();
void UnlockColumn();
- BOOL DoesColonFollow();
+ sal_Bool DoesColonFollow();
- BOOL NextSym(); // naechstes Symbol lesen
+ sal_Bool NextSym(); // naechstes Symbol lesen
const String& GetSym() { return aSym; }
SbxDataType GetType() { return eScanType; }
double GetDbl() { return nVal; }
@@ -122,22 +122,22 @@ class BasicSimpleCharClass
static LetterTable aLetterTable;
public:
- static BOOL isAlpha( sal_Unicode c, bool bCompatible )
+ static sal_Bool isAlpha( sal_Unicode c, bool bCompatible )
{
- BOOL bRet = (c >= 'a' && c <= 'z') || (c >= 'A' && c <= 'Z')
+ sal_Bool bRet = (c >= 'a' && c <= 'z') || (c >= 'A' && c <= 'Z')
|| (bCompatible && aLetterTable.isLetter( c ));
return bRet;
}
- static BOOL isDigit( sal_Unicode c )
+ static sal_Bool isDigit( sal_Unicode c )
{
- BOOL bRet = (c >= '0' && c <= '9');
+ sal_Bool bRet = (c >= '0' && c <= '9');
return bRet;
}
- static BOOL isAlphaNumeric( sal_Unicode c, bool bCompatible )
+ static sal_Bool isAlphaNumeric( sal_Unicode c, bool bCompatible )
{
- BOOL bRet = isDigit( c ) || isAlpha( c, bCompatible );
+ sal_Bool bRet = isDigit( c ) || isAlpha( c, bCompatible );
return bRet;
}
};
diff --git a/basic/source/inc/symtbl.hxx b/basic/source/inc/symtbl.hxx
index b8457b3c811b..adfee46b4aed 100644..100755
--- a/basic/source/inc/symtbl.hxx
+++ b/basic/source/inc/symtbl.hxx
@@ -59,12 +59,12 @@ class SbiStringPool { // String-Pool
public:
SbiStringPool( SbiParser* );
~SbiStringPool();
- USHORT GetSize() const { return aData.Count(); }
- // AB 8.4.1999, Default wegen #64236 auf TRUE geaendert
- // Wenn der Bug sauber behoben ist, wieder auf FALSE aendern.
- short Add( const String&, BOOL=TRUE );
+ sal_uInt16 GetSize() const { return aData.Count(); }
+ // AB 8.4.1999, Default wegen #64236 auf sal_True geaendert
+ // Wenn der Bug sauber behoben ist, wieder auf sal_False aendern.
+ short Add( const String&, sal_Bool=sal_True );
short Add( double, SbxDataType );
- const String& Find( USHORT ) const;
+ const String& Find( sal_uInt16 ) const;
SbiParser* GetParser() { return pParser; }
};
@@ -81,8 +81,8 @@ protected:
SbiSymPool* pParent; // uebergeordneter Symbol-Pool
SbiParser* pParser; // der Parser
SbiSymScope eScope; // Scope des Pools
- USHORT nProcId; // aktuelles ProcId fuer STATIC-Variable
- USHORT nCur; // Iterator
+ sal_uInt16 nProcId; // aktuelles ProcId fuer STATIC-Variable
+ sal_uInt16 nCur; // Iterator
public:
SbiSymPool( SbiStringPool&, SbiSymScope );
~SbiSymPool();
@@ -91,7 +91,7 @@ public:
void SetParent( SbiSymPool* p ) { pParent = p; }
void SetProcId( short n ) { nProcId = n; }
- USHORT GetSize() const { return aData.Count(); }
+ sal_uInt16 GetSize() const { return aData.Count(); }
SbiSymScope GetScope() const { return eScope; }
void SetScope( SbiSymScope s ) { eScope = s; }
SbiParser* GetParser() { return pParser; }
@@ -100,12 +100,12 @@ public:
SbiProcDef* AddProc( const String& );// Prozedur hinzufuegen
void Add( SbiSymDef* ); // Symbol uebernehmen
SbiSymDef* Find( const String& ) const;// Variablenname
- SbiSymDef* FindId( USHORT ) const; // Variable per ID suchen
- SbiSymDef* Get( USHORT ) const; // Variable per Position suchen
+ SbiSymDef* FindId( sal_uInt16 ) const; // Variable per ID suchen
+ SbiSymDef* Get( sal_uInt16 ) const; // Variable per Position suchen
SbiSymDef* First(), *Next(); // Iteratoren
- UINT32 Define( const String& ); // Label definieren
- UINT32 Reference( const String& ); // Label referenzieren
+ sal_uInt32 Define( const String& ); // Label definieren
+ sal_uInt32 Reference( const String& ); // Label referenzieren
void CheckRefs(); // offene Referenzen suchen
};
@@ -120,21 +120,21 @@ protected:
SbiSymPool* pPool; // Pool fuer Unterelemente
short nLen; // Stringlaenge bei STRING*n
short nDims; // Array-Dimensionen
- USHORT nId; // Symbol-Nummer
- USHORT nTypeId; // String-ID des Datentyps (Dim X AS Dytentyp)
- USHORT nProcId; // aktuelles ProcId fuer STATIC-Variable
- USHORT nPos; // Positions-Nummer
- UINT32 nChain; // Backchain-Kette
- BOOL bNew : 1; // TRUE: Dim As New...
- BOOL bChained : 1; // TRUE: Symbol ist in Code definiert
- BOOL bByVal : 1; // TRUE: ByVal-Parameter
- BOOL bOpt : 1; // TRUE: optionaler Parameter
- BOOL bStatic : 1; // TRUE: STATIC-Variable
- BOOL bAs : 1; // TRUE: Datentyp per AS XXX definiert
- BOOL bGlobal : 1; // TRUE: Global-Variable
- BOOL bParamArray : 1; // TRUE: ParamArray parameter
- BOOL bWithEvents : 1; // TRUE: Declared WithEvents
- USHORT nDefaultId; // Symbol number of default value
+ sal_uInt16 nId; // Symbol-Nummer
+ sal_uInt16 nTypeId; // String-ID des Datentyps (Dim X AS Dytentyp)
+ sal_uInt16 nProcId; // aktuelles ProcId fuer STATIC-Variable
+ sal_uInt16 nPos; // Positions-Nummer
+ sal_uInt32 nChain; // Backchain-Kette
+ sal_Bool bNew : 1; // sal_True: Dim As New...
+ sal_Bool bChained : 1; // sal_True: Symbol ist in Code definiert
+ sal_Bool bByVal : 1; // sal_True: ByVal-Parameter
+ sal_Bool bOpt : 1; // sal_True: optionaler Parameter
+ sal_Bool bStatic : 1; // sal_True: STATIC-Variable
+ sal_Bool bAs : 1; // sal_True: Datentyp per AS XXX definiert
+ sal_Bool bGlobal : 1; // sal_True: Global-Variable
+ sal_Bool bParamArray : 1; // sal_True: ParamArray parameter
+ sal_Bool bWithEvents : 1; // sal_True: Declared WithEvents
+ sal_uInt16 nDefaultId; // Symbol number of default value
short nFixedStringLength; // String length in: Dim foo As String*Length
public:
SbiSymDef( const String& );
@@ -146,42 +146,42 @@ public:
virtual void SetType( SbxDataType );
const String& GetName();
SbiSymScope GetScope() const;
- USHORT GetProcId() const{ return nProcId; }
- UINT32 GetAddr() const { return nChain; }
- USHORT GetId() const { return nId; }
- USHORT GetTypeId() const{ return nTypeId; }
- void SetTypeId( USHORT n ) { nTypeId = n; eType = SbxOBJECT; }
- USHORT GetPos() const { return nPos; }
+ sal_uInt16 GetProcId() const{ return nProcId; }
+ sal_uInt32 GetAddr() const { return nChain; }
+ sal_uInt16 GetId() const { return nId; }
+ sal_uInt16 GetTypeId() const{ return nTypeId; }
+ void SetTypeId( sal_uInt16 n ) { nTypeId = n; eType = SbxOBJECT; }
+ sal_uInt16 GetPos() const { return nPos; }
void SetLen( short n ){ nLen = n; }
short GetLen() const { return nLen; }
void SetDims( short n ) { nDims = n; }
short GetDims() const { return nDims; }
- BOOL IsDefined() const{ return bChained; }
- void SetOptional() { bOpt = TRUE; }
- void SetParamArray() { bParamArray = TRUE; }
- void SetWithEvents() { bWithEvents = TRUE; }
- void SetByVal( BOOL bByVal_ = TRUE )
+ sal_Bool IsDefined() const{ return bChained; }
+ void SetOptional() { bOpt = sal_True; }
+ void SetParamArray() { bParamArray = sal_True; }
+ void SetWithEvents() { bWithEvents = sal_True; }
+ void SetByVal( sal_Bool bByVal_ = sal_True )
{ bByVal = bByVal_; }
- void SetStatic( BOOL bAsStatic = TRUE ) { bStatic = bAsStatic; }
- void SetNew() { bNew = TRUE; }
- void SetDefinedAs() { bAs = TRUE; }
- void SetGlobal(BOOL b){ bGlobal = b; }
- void SetDefaultId( USHORT n ) { nDefaultId = n; }
- USHORT GetDefaultId( void ) { return nDefaultId; }
- BOOL IsOptional() const{ return bOpt; }
- BOOL IsParamArray() const{ return bParamArray; }
- BOOL IsWithEvents() const{ return bWithEvents; }
- BOOL IsByVal() const { return bByVal; }
- BOOL IsStatic() const { return bStatic; }
- BOOL IsNew() const { return bNew; }
- BOOL IsDefinedAs() const { return bAs; }
- BOOL IsGlobal() const { return bGlobal; }
+ void SetStatic( sal_Bool bAsStatic = sal_True ) { bStatic = bAsStatic; }
+ void SetNew() { bNew = sal_True; }
+ void SetDefinedAs() { bAs = sal_True; }
+ void SetGlobal(sal_Bool b){ bGlobal = b; }
+ void SetDefaultId( sal_uInt16 n ) { nDefaultId = n; }
+ sal_uInt16 GetDefaultId( void ) { return nDefaultId; }
+ sal_Bool IsOptional() const{ return bOpt; }
+ sal_Bool IsParamArray() const{ return bParamArray; }
+ sal_Bool IsWithEvents() const{ return bWithEvents; }
+ sal_Bool IsByVal() const { return bByVal; }
+ sal_Bool IsStatic() const { return bStatic; }
+ sal_Bool IsNew() const { return bNew; }
+ sal_Bool IsDefinedAs() const { return bAs; }
+ sal_Bool IsGlobal() const { return bGlobal; }
short GetFixedStringLength( void ) const { return nFixedStringLength; }
void SetFixedStringLength( short n ) { nFixedStringLength = n; }
SbiSymPool& GetPool();
- UINT32 Define(); // Symbol in Code definieren
- UINT32 Reference(); // Symbol in Code referenzieren
+ sal_uInt32 Define(); // Symbol in Code definieren
+ sal_uInt32 Reference(); // Symbol in Code referenzieren
private:
SbiSymDef( const SbiSymDef& );
@@ -193,14 +193,14 @@ class SbiProcDef : public SbiSymDef { // Prozedur-Definition (aus Basic):
SbiSymPool aLabels; // lokale Sprungziele
String aLibName; // LIB "name"
String aAlias; // ALIAS "name"
- USHORT nLine1, nLine2; // Zeilenbereich
+ sal_uInt16 nLine1, nLine2; // Zeilenbereich
PropertyMode mePropMode; // Marks if this is a property procedure and which
String maPropName; // Property name if property procedure (!= proc name)
- BOOL bCdecl : 1; // TRUE: CDECL angegeben
- BOOL bPublic : 1; // TRUE: proc ist PUBLIC
- BOOL mbProcDecl : 1; // TRUE: instanciated by SbiParser::ProcDecl
+ sal_Bool bCdecl : 1; // sal_True: CDECL angegeben
+ sal_Bool bPublic : 1; // sal_True: proc ist PUBLIC
+ sal_Bool mbProcDecl : 1; // sal_True: instanciated by SbiParser::ProcDecl
public:
- SbiProcDef( SbiParser*, const String&, BOOL bProcDecl=false );
+ SbiProcDef( SbiParser*, const String&, sal_Bool bProcDecl=false );
virtual ~SbiProcDef();
virtual SbiProcDef* GetProcDef();
virtual void SetType( SbxDataType );
@@ -209,15 +209,15 @@ public:
SbiSymPool& GetLocals() { return GetPool();}
String& GetLib() { return aLibName; }
String& GetAlias() { return aAlias; }
- void SetPublic( BOOL b ) { bPublic = b; }
- BOOL IsPublic() const { return bPublic; }
- void SetCdecl( BOOL b = TRUE) { bCdecl = b; }
- BOOL IsCdecl() const { return bCdecl; }
- BOOL IsUsedForProcDecl() const { return mbProcDecl; }
- void SetLine1( USHORT n ) { nLine1 = n; }
- USHORT GetLine1() const { return nLine1; }
- void SetLine2( USHORT n ) { nLine2 = n; }
- USHORT GetLine2() const { return nLine2; }
+ void SetPublic( sal_Bool b ) { bPublic = b; }
+ sal_Bool IsPublic() const { return bPublic; }
+ void SetCdecl( sal_Bool b = sal_True) { bCdecl = b; }
+ sal_Bool IsCdecl() const { return bCdecl; }
+ sal_Bool IsUsedForProcDecl() const { return mbProcDecl; }
+ void SetLine1( sal_uInt16 n ) { nLine1 = n; }
+ sal_uInt16 GetLine1() const { return nLine1; }
+ void SetLine2( sal_uInt16 n ) { nLine2 = n; }
+ sal_uInt16 GetLine2() const { return nLine2; }
PropertyMode getPropertyMode() { return mePropMode; }
void setPropertyMode( PropertyMode ePropMode );
const String& GetPropName() { return maPropName; }
diff --git a/basic/source/inc/token.hxx b/basic/source/inc/token.hxx
index 544eef119e01..deb6764f2e2c 100644..100755
--- a/basic/source/inc/token.hxx
+++ b/basic/source/inc/token.hxx
@@ -141,25 +141,25 @@ class SbiTokenizer : public SbiScanner {
protected:
SbiToken eCurTok; // aktuelles Token
SbiToken ePush; // Pushback-Token
- USHORT nPLine, nPCol1, nPCol2; // Pushback-Location
- BOOL bEof; // TRUE bei Dateiende
- BOOL bEos; // TRUE bei Statement-Ende
- BOOL bKeywords; // TRUE, falls Keywords geparst werden
- BOOL bAs; // letztes Keyword war AS
- BOOL bErrorIsSymbol; // Handle Error token as Symbol, not keyword
+ sal_uInt16 nPLine, nPCol1, nPCol2; // Pushback-Location
+ sal_Bool bEof; // sal_True bei Dateiende
+ sal_Bool bEos; // sal_True bei Statement-Ende
+ sal_Bool bKeywords; // sal_True, falls Keywords geparst werden
+ sal_Bool bAs; // letztes Keyword war AS
+ sal_Bool bErrorIsSymbol; // Handle Error token as Symbol, not keyword
public:
SbiTokenizer( const ::rtl::OUString&, StarBASIC* = NULL );
~SbiTokenizer();
- inline BOOL IsEof() { return bEof; }
- inline BOOL IsEos() { return bEos; }
+ inline sal_Bool IsEof() { return bEof; }
+ inline sal_Bool IsEos() { return bEos; }
void Push( SbiToken ); // Pushback eines Tokens
const String& Symbol( SbiToken );// Rueckumwandlung
SbiToken Peek(); // das naechste Token lesen
SbiToken Next(); // Ein Token lesen
- BOOL MayBeLabel( BOOL= FALSE ); // Kann es ein Label sein?
+ sal_Bool MayBeLabel( sal_Bool= sal_False ); // Kann es ein Label sein?
void Hilite( SbTextPortions& ); // Syntax-Highlighting
@@ -168,14 +168,14 @@ public:
void Error( SbError, const char* );
void Error( SbError, String );
- void Keywords( BOOL b ) { bKeywords = b; }
+ void Keywords( sal_Bool b ) { bKeywords = b; }
- static BOOL IsEoln( SbiToken t )
- { return BOOL( t == EOS || t == EOLN || t == REM ); }
- static BOOL IsKwd( SbiToken t )
- { return BOOL( t >= FIRSTKWD && t <= LASTKWD ); }
- static BOOL IsExtra( SbiToken t )
- { return BOOL( t >= FIRSTEXTRA ); }
+ static sal_Bool IsEoln( SbiToken t )
+ { return sal_Bool( t == EOS || t == EOLN || t == REM ); }
+ static sal_Bool IsKwd( SbiToken t )
+ { return sal_Bool( t >= FIRSTKWD && t <= LASTKWD ); }
+ static sal_Bool IsExtra( SbiToken t )
+ { return sal_Bool( t >= FIRSTEXTRA ); }
};